import requests
import json

def update_testcase_status(apiKey,apiUrl,board_id,item_id, **columnValuesDict):  
    request_headers = {"Authorization" : apiKey}
    for key in columnValuesDict:
        columns_Dict = {
        key: columnValuesDict[key],
        }  
        vars = {
       'item_id' : int(item_id),
        'board_id' : int(board_id),
         'columnVals' : json.dumps(columns_Dict)
         } 
        query =  'mutation ( $board_id: Int!, $item_id: Int!,  $columnVals: JSON!) {change_multiple_column_values (board_id: $board_id, item_id: $item_id, column_values: $columnVals) {id}}'
        data = {'query' : query,'variables' : vars}
        requests.post(url=apiUrl, json=data, headers=request_headers)





from setuptools import find_packages, setup
setup(
    name='updateMondayItemLib',
    packages=find_packages(),
    version='0.1.1',
    description='Update the existing items on monday board',
    author='Bilal Ashraf',
    license='MIT',
    long_description="This package allows you to update columns against item on monday.com board.It takes following parameters apiKey,apiUrl,board_id,item_id, **columnValuesDict. Columns ID and their values are passed as key value pair in dictionary.",
    long_description_content_type='text/markdown'
)